covid19.testing.data: function to read data related to covid19 Testing from OWID repo
Description
function to read data related to covid19 Testing from OWID repo
Usage
covid19.testing.data(tgt = "testing", disclaimer = TRUE)
Arguments
tgt
selects between time series data ('testing') and details and overall view of the data ("testing.details")
disclaimer
indicates whether the information about the source of the data is disclosed
Value
dataframe containing list of countries (Entity) and testing data