Learn R Programming

covid19.analytics (version 1.0)

totals.plt: function to plot total number of cases per day for different groups

Description

function to plot total number of cases per day for different groups

Usage

totals.plt(
  data0 = NULL,
  geo.loc = NULL,
  interactive.fig = TRUE,
  fileName = NULL
)

Arguments

data0

time series dataset to process, default all the possible cases: 'confirmed' and 'deaths' for all countries/regions

geo.loc

geographical location, country/region or province/state to restrict the analysis to

interactive.fig

swith to turn off/on an interactive plot

fileName

file where to save the HTML version of the interactive figure

Examples

Run this code
# NOT RUN {
# retrieve time series data
TS.data <- covid19.data("ts-ALL")

# static and interactive plot 
totals.plt(TS.data)

# }

Run the code above in your browser using DataLab