powered by
function to plot total number of cases per day for different groups
totals.plt( data0 = NULL, geo.loc = NULL, interactive.fig = TRUE, fileName = NULL )
time series dataset to process, default all the possible cases: 'confirmed' and 'deaths' for all countries/regions
geographical location, country/region or province/state to restrict the analysis to
swith to turn off/on an interactive plot
file where to save the HTML version of the interactive figure
# NOT RUN { # retrieve time series data TS.data <- covid19.data("ts-ALL") # static and interactive plot totals.plt(TS.data) # }
Run the code above in your browser using DataLab